==> jc-1.4.0.tar.gz: java/nio/charset/CodingErrorAction.h <==
// public class java.nio.charset.CodingErrorAction

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d05e2a1e302ececd java_nio_charset_CodingErrorAction

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_nio_charset_CodingErrorAction_H_
#define _JC_java_nio_charset_CodingErrorAction_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_nio_charset_CodingErrorAction$object;

// Typedefs
typedef struct _jc_java_nio_charset_CodingErrorAction$sub_refs	_jc_java_nio_charset_CodingErrorAction$sub_refs;
typedef struct _jc_java_nio_charset_CodingErrorAction$sub_nonrefs	_jc_java_nio_charset_CodingErrorAction$sub_nonrefs;
typedef struct _jc_java_nio_charset_CodingErrorAction$refs	_jc_java_nio_charset_CodingErrorAction$refs;
typedef struct _jc_java_nio_charset_CodingErrorAction$nonrefs	_jc_java_nio_charset_CodingErrorAction$nonrefs;
typedef struct _jc_java_nio_charset_CodingErrorAction$object	_jc_java_nio_charset_CodingErrorAction$object;

typedef struct _jc_java_nio_charset_CodingErrorAction$fields_struct	_jc_java_nio_charset_CodingErrorAction$fields_struct;
typedef const struct _jc_java_nio_charset_CodingErrorAction$vmethods	_jc_java_nio_charset_CodingErrorAction$vmethods;
typedef const struct _jc_java_nio_charset_CodingErrorAction$vtable	_jc_java_nio_charset_CodingErrorAction$vtable;
typedef const struct _jc_java_nio_charset_CodingErrorAction$vtype	_jc_java_nio_charset_CodingErrorAction$vtype;

// Class fields structure
struct _jc_java_nio_charset_CodingErrorAction$fields_struct {
	struct _jc_java_nio_charset_CodingErrorAction$object	*IGNORE;
	struct _jc_java_nio_charset_CodingErrorAction$object	*REPLACE;
	struct _jc_java_nio_charset_CodingErrorAction$object	*REPORT;
};
extern _jc_java_nio_charset_CodingErrorAction$fields_struct _jc_java_nio_charset_CodingErrorAction$class_fields;

// Constructors
extern void _jc_java_nio_charset_CodingErrorAction$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_nio_charset_CodingErrorAction$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_java_nio_charset_CodingErrorAction$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_nio_charset_CodingErrorAction$object *);

// Virtual method descriptors
extern _jc_method _jc_java_nio_charset_CodingErrorAction$method_info$toString$7ea43b33b80a3070;

// Static methods
extern void _jc_java_nio_charset_CodingErrorAction$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_java_nio_charset_CodingErrorAction$vmethods {
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_nio_charset_CodingErrorAction$object *);
};

// Vtable
struct _jc_java_nio_charset_CodingErrorAction$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_nio_charset_CodingErrorAction$vmethods	java_nio_charset_CodingErrorAction;
};

// Vtype
struct _jc_java_nio_charset_CodingErrorAction$vtype {
	_jc_type			type;
	_jc_java_nio_charset_CodingErrorAction$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_nio_charset_CodingErrorAction$sub_refs {
	struct _jc_java_lang_String$object	*name;
};

// Reference instance fields (object)
struct _jc_java_nio_charset_CodingErrorAction$refs {
    _jc_java_nio_charset_CodingErrorAction$sub_refs	java_nio_charset_CodingErrorAction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_nio_charset_CodingErrorAction$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_nio_charset_CodingErrorAction$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_nio_charset_CodingErrorAction$sub_nonrefs	java_nio_charset_CodingErrorAction;
};

// Object instance structure
struct _jc_java_nio_charset_CodingErrorAction$object {
	_jc_java_nio_charset_CodingErrorAction$refs	refs[0];
	_jc_word		lockword;
	_jc_java_nio_charset_CodingErrorAction$vtype	*vtype;
	_jc_java_nio_charset_CodingErrorAction$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_nio_charset_CodingErrorAction$vtype _jc_java_nio_charset_CodingErrorAction$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_nio_charset_CodingErrorAction, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_nio_charset_CodingErrorAction$class_object;

#endif	/* _JC_java_nio_charset_CodingErrorAction_H_ */

==> jc-1.4.6.tar.gz: java/nio/charset/CodingErrorAction.h <==
// public class java.nio.charset.CodingErrorAction

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d05e2a1e302ececd java_nio_charset_CodingErrorAction

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_nio_charset_CodingErrorAction_H_
#define _JC_java_nio_charset_CodingErrorAction_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_nio_charset_CodingErrorAction$object;

// Typedefs
typedef struct _jc_java_nio_charset_CodingErrorAction$sub_refs	_jc_java_nio_charset_CodingErrorAction$sub_refs;
typedef struct _jc_java_nio_charset_CodingErrorAction$sub_nonrefs	_jc_java_nio_charset_CodingErrorAction$sub_nonrefs;
typedef struct _jc_java_nio_charset_CodingErrorAction$refs	_jc_java_nio_charset_CodingErrorAction$refs;
typedef struct _jc_java_nio_charset_CodingErrorAction$nonrefs	_jc_java_nio_charset_CodingErrorAction$nonrefs;
typedef struct _jc_java_nio_charset_CodingErrorAction$object	_jc_java_nio_charset_CodingErrorAction$object;

typedef struct _jc_java_nio_charset_CodingErrorAction$fields_struct	_jc_java_nio_charset_CodingErrorAction$fields_struct;
typedef const struct _jc_java_nio_charset_CodingErrorAction$vmethods	_jc_java_nio_charset_CodingErrorAction$vmethods;
typedef const struct _jc_java_nio_charset_CodingErrorAction$vtable	_jc_java_nio_charset_CodingErrorAction$vtable;
typedef const struct _jc_java_nio_charset_CodingErrorAction$vtype	_jc_java_nio_charset_CodingErrorAction$vtype;

// Class fields structure
struct _jc_java_nio_charset_CodingErrorAction$fields_struct {
	struct _jc_java_nio_charset_CodingErrorAction$object	*IGNORE;
	struct _jc_java_nio_charset_CodingErrorAction$object	*REPLACE;
	struct _jc_java_nio_charset_CodingErrorAction$object	*REPORT;
};
extern _jc_java_nio_charset_CodingErrorAction$fields_struct _jc_java_nio_charset_CodingErrorAction$class_fields;

// Constructors
extern void _jc_java_nio_charset_CodingErrorAction$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_nio_charset_CodingErrorAction$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_java_nio_charset_CodingErrorAction$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_nio_charset_CodingErrorAction$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_nio_charset_CodingErrorAction$method_info$toString$7ea43b33b80a3070;

// Static methods
extern void _jc_java_nio_charset_CodingErrorAction$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_nio_charset_CodingErrorAction$vmethods {
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_nio_charset_CodingErrorAction$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_nio_charset_CodingErrorAction$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_nio_charset_CodingErrorAction$vmethods	java_nio_charset_CodingErrorAction;
};

// Vtype
struct _jc_java_nio_charset_CodingErrorAction$vtype {
	_jc_type			type;
	_jc_java_nio_charset_CodingErrorAction$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_nio_charset_CodingErrorAction$sub_refs {
	struct _jc_java_lang_String$object	*name;
};

// Reference instance fields (object)
struct _jc_java_nio_charset_CodingErrorAction$refs {
    _jc_java_nio_charset_CodingErrorAction$sub_refs	java_nio_charset_CodingErrorAction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_nio_charset_CodingErrorAction$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_nio_charset_CodingErrorAction$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_nio_charset_CodingErrorAction$sub_nonrefs	java_nio_charset_CodingErrorAction;
};

// Object instance structure
struct _jc_java_nio_charset_CodingErrorAction$object {
	_jc_java_nio_charset_CodingErrorAction$refs	refs[0];
	_jc_word		lockword;
	_jc_java_nio_charset_CodingErrorAction$vtype	*vtype;
	_jc_java_nio_charset_CodingErrorAction$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_nio_charset_CodingErrorAction$vtype _jc_java_nio_charset_CodingErrorAction$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_nio_charset_CodingErrorAction, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_nio_charset_CodingErrorAction$class_object;

#endif	/* _JC_java_nio_charset_CodingErrorAction_H_ */
